"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const general_1 = require("../../helpers/general");
function Throttle(timeMs) {
    return general_1.generateFunctionDecorator('Throttle', decorator, timeMs);
}
exports.Throttle = Throttle;
function decorator(fn, timeMs) {
    let timeout;
    let nextCall;
    return function (...args) {
        const now = Date.now();
        if (general_1.isUndefined(nextCall) || nextCall <= timeMs) {
            nextCall = now + timeMs;
            return fn.apply(this, args);
        }
        else {
            const remaining = nextCall - now;
            timeout && clearTimeout(timeout);
            timeout = setTimeout(() => fn.apply(this, args), remaining);
        }
    };
}
//# sourceMappingURL=throttle.js.map